==> haskell-htf-0.15.0.1-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-htf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HTF
version:              0.15.0.1
visibility:           public
id:                   HTF-0.15.0.1-DwZ5lq22xMAFkia7pwCWwL
key:                  HTF-0.15.0.1-DwZ5lq22xMAFkia7pwCWwL
license:              LGPL-2.1-only
copyright:            (c) 2005-2023 Stefan Wehr
maintainer:           Stefan Wehr
author:               Stefan Wehr
stability:            Beta
homepage:             https://github.com/skogsbaer/HTF/
synopsis:             The Haskell Test Framework
description:
    The Haskell Test Framework (/HTF/ for short) lets you define and organize unit tests,
    QuickCheck properties,
    and black box tests in an
    easy and convenient way. HTF uses a custom preprocessor that collects
    test definitions automatically.

    HTF produces highly readable output
    for failing test cases: it provides exact file name and line number
    information,
    it colors and pretty prints expected and
    actual results, and it displays a diff highlighting the mismatching parts.

    The documentation of the "Test.Framework.Tutorial" module
    provides a tutorial for HTF. The /sample/ directory in
    the HTF repo provides a good starting point for
    a project using HTF.

category:             Testing
abi:                  7a9f2923a9b49cb4ff3abe39ab55cc8f
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.AssertM Test.Framework.BlackBoxTest
    Test.Framework.HUnitWrapper Test.Framework.History
    Test.Framework.JsonOutput Test.Framework.Location
    Test.Framework.Preprocessor Test.Framework.Pretty
    Test.Framework.PrettyHaskell Test.Framework.QuickCheckWrapper
    Test.Framework.TestInterface Test.Framework.TestManager
    Test.Framework.TestTypes Test.Framework.ThreadPool
    Test.Framework.Tutorial Test.Framework.XmlOutput

hidden-modules:
    Paths_HTF Test.Framework.CmdlineOptions Test.Framework.Colors
    Test.Framework.Diff Test.Framework.Process
    Test.Framework.TestReporter Test.Framework.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/HTF-0.15.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/HTF-0.15.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-htf
hs-libraries:         HSHTF-0.15.0.1-DwZ5lq22xMAFkia7pwCWwL
depends:
    Diff-0.4.1-FQGoMszL7yvHgYjHqpLdBw
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
    QuickCheck-2.14.3-GYIzHRC98oX2ojVETG14rD
    aeson-2.1.2.1-EcnOkqJy6qkFyx4PSoTHhT array-0.5.4.0 base-4.16.4.0
    base64-bytestring-1.2.1.0-10uzYZsf0KVKU2D9qeaVY8
    bytestring-0.11.4.0 containers-0.6.5.1
    cpphs-1.20.9.1-1K2ccivGg76HqdQttHm61m directory-1.3.6.2
    haskell-src-1.0.4.1-GpeSq9M9iD08ND0JwzMXGp
    lifted-base-0.2.3.12-DQLsZto8uK0Aez8LuH3ZRC
    monad-control-1.0.3.1-J6JgsySNufR1aBAHpQ3Eh2 mtl-2.2.2
    old-time-1.1.0.4-Dlc8YwGlkPi2Y3VNXkrOFg pretty-1.1.3.6
    process-1.6.16.0 random-1.2.1.2-F9rVStWFtZE3PBeMKQuK89
    regex-compat-0.95.2.1-FJHZPtlQfxdJ4utGNMgjH1 text-1.2.5.0
    time-1.11.1.1 unix-2.7.2.2 vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP
    xmlgen-0.6.2.2-FqHS6b8CYNuJETRJKvKEe9

haddock-interfaces:   /usr/share/doc/haskell-htf/html/HTF.haddock
haddock-html:         /usr/share/doc/haskell-htf/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-htf-0.15.0.1-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-htf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HTF
version:              0.15.0.1
visibility:           public
id:                   HTF-0.15.0.1-AMaMAp2xUjAKehS7eIhWN0
key:                  HTF-0.15.0.1-AMaMAp2xUjAKehS7eIhWN0
license:              LGPL-2.1-only
copyright:            (c) 2005-2023 Stefan Wehr
maintainer:           Stefan Wehr
author:               Stefan Wehr
stability:            Beta
homepage:             https://github.com/skogsbaer/HTF/
synopsis:             The Haskell Test Framework
description:
    The Haskell Test Framework (/HTF/ for short) lets you define and organize unit tests,
    QuickCheck properties,
    and black box tests in an
    easy and convenient way. HTF uses a custom preprocessor that collects
    test definitions automatically.

    HTF produces highly readable output
    for failing test cases: it provides exact file name and line number
    information,
    it colors and pretty prints expected and
    actual results, and it displays a diff highlighting the mismatching parts.

    The documentation of the "Test.Framework.Tutorial" module
    provides a tutorial for HTF. The /sample/ directory in
    the HTF repo provides a good starting point for
    a project using HTF.

category:             Testing
abi:                  2bd1cb8807c483ceaa472a02ea3a2c81
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.AssertM Test.Framework.BlackBoxTest
    Test.Framework.HUnitWrapper Test.Framework.History
    Test.Framework.JsonOutput Test.Framework.Location
    Test.Framework.Preprocessor Test.Framework.Pretty
    Test.Framework.PrettyHaskell Test.Framework.QuickCheckWrapper
    Test.Framework.TestInterface Test.Framework.TestManager
    Test.Framework.TestTypes Test.Framework.ThreadPool
    Test.Framework.Tutorial Test.Framework.XmlOutput

hidden-modules:
    Paths_HTF Test.Framework.CmdlineOptions Test.Framework.Colors
    Test.Framework.Diff Test.Framework.Process
    Test.Framework.TestReporter Test.Framework.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/HTF-0.15.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/HTF-0.15.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-htf
hs-libraries:         HSHTF-0.15.0.1-AMaMAp2xUjAKehS7eIhWN0
depends:
    Diff-0.4.1-FQGoMszL7yvHgYjHqpLdBw
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
    QuickCheck-2.14.3-GYIzHRC98oX2ojVETG14rD
    aeson-2.1.2.1-LOsc8VZqmR4FTSS4ItJTX9 array-0.5.4.0 base-4.16.4.0
    base64-bytestring-1.2.1.0-10uzYZsf0KVKU2D9qeaVY8
    bytestring-0.11.4.0 containers-0.6.5.1
    cpphs-1.20.9.1-1K2ccivGg76HqdQttHm61m directory-1.3.6.2
    haskell-src-1.0.4.1-GpeSq9M9iD08ND0JwzMXGp
    lifted-base-0.2.3.12-DQLsZto8uK0Aez8LuH3ZRC
    monad-control-1.0.3.1-J6JgsySNufR1aBAHpQ3Eh2 mtl-2.2.2
    old-time-1.1.0.4-Dlc8YwGlkPi2Y3VNXkrOFg pretty-1.1.3.6
    process-1.6.16.0 random-1.2.1.2-F9rVStWFtZE3PBeMKQuK89
    regex-compat-0.95.2.1-FJHZPtlQfxdJ4utGNMgjH1 text-1.2.5.0
    time-1.11.1.1 unix-2.7.2.2 vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP
    xmlgen-0.6.2.2-FqHS6b8CYNuJETRJKvKEe9

haddock-interfaces:   /usr/share/doc/haskell-htf/html/HTF.haddock
haddock-html:         /usr/share/doc/haskell-htf/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
